@@ -121,8 +121,12 @@ void ConfigDialog::browseAspell()
 #ifdef USB_VERSION
 QDir spelldir(QCoreApplication::applicationDirPath());
 #else
+#ifdef DEBIAN_SPELLDIR
+QDir spelldir(PREFIX"/share/myspell/dicts");
+#else
 QDir spelldir(PREFIX"/share/texmaker");
 #endif
+#endif
 
 #endif
 #if defined( Q_WS_MACX )
