@@ -39,6 +39,7 @@ QPalette p = palette();
 p.setColor(QPalette::Inactive, QPalette::Highlight,p.color(QPalette::Active, QPalette::Highlight));
 p.setColor(QPalette::Inactive, QPalette::HighlightedText,p.color(QPalette::Active, QPalette::HighlightedText));
 setPalette(p);
+setFrameStyle(QFrame::NoFrame);
 //setAcceptRichText(false);
 setLineWidth(0);
 setFrameShape(QFrame::NoFrame);
@@ -219,10 +220,16 @@ a = menu->addAction(tr("Select All"), this, SLOT(selectAll()));
 a->setShortcut(Qt::CTRL+Qt::Key_A);
 a->setEnabled(!document()->isEmpty());
 menu->addSeparator();
+if (!document()->isEmpty() && !inlinecheckSpelling)
+{
 a = menu->addAction(tr("Check Spelling Word"), this, SLOT(checkSpellingWord()));
-a->setEnabled(!document()->isEmpty() && !inlinecheckSpelling);
+//a->setEnabled(!document()->isEmpty() && !inlinecheckSpelling);
+}
+if (textCursor().hasSelection())
+{
 a = menu->addAction(tr("Check Spelling Selection"), this, SLOT(checkSpellingDocument()));
-a->setEnabled(textCursor().hasSelection());
+//a->setEnabled(textCursor().hasSelection());
+}
 a = menu->addAction(tr("Check Spelling Document"), this, SLOT(checkSpellingDocument()));
 a->setEnabled(!document()->isEmpty() /*&& !textCursor().hasSelection()*/);
 if (endBlock>=0)
@@ -237,6 +244,7 @@ if (endBlock>=0)
   }
 menu->addSeparator();
 a=new QAction(tr("Jump to pdf"),menu);
+a->setShortcut(Qt::CTRL+Qt::Key_Space);
 a->setData(QVariant(cursorForPosition(e->pos()).blockNumber() + 1));
 connect(a, SIGNAL(triggered()), this, SLOT(jumpToPdf()));
 menu->addAction(a);
@@ -338,7 +346,7 @@ if (cur.hasSelection())
 		end++;
 		go=cur.movePosition(QTextCursor::NextBlock,QTextCursor::MoveAnchor);
 		}
-}	
+      }	
 }
 
 void LatexEditor::indentSelection()
@@ -968,6 +976,10 @@ else if ((e->key()==Qt::Key_Enter)||(e->key()==Qt::Key_Return))
 		}
 	cursor.endEditBlock();
 	}
+else if (((e->modifiers() & ~Qt::ShiftModifier) == Qt::ControlModifier) && e->key()==Qt::Key_Space) 
+  {
+  emit requestpdf(textCursor().blockNumber() + 1);
+  }
 else QPlainTextEdit::keyPressEvent(e);
 if (c && !c->popup()->isVisible()) 
 	{
@@ -1054,6 +1066,7 @@ tc.movePosition(QTextCursor::NextCharacter,QTextCursor::KeepAnchor,w-t-1+r);
 tc.removeSelectedText();
 int pos=tc.position();
 QString insert_word = completion;
+QString env;
 QRegExp rbb("begin\\{\\s*([A-Za-z_]+)\\}");
 //QRegExp rbb("begin\\{\\s*(.*)\\}");
 if (completion.contains(rbb)) 
@@ -1061,7 +1074,9 @@ if (completion.contains(rbb))
 	tc.insertText(insert_word);
 	insertNewLine();
 	insertNewLine();
-	tc.insertText("\\end{"+rbb.cap(1)+"}");
+	tc.select(QTextCursor::WordUnderCursor);
+	env=rbb.cap(1);
+	tc.insertText("\\end{"+env+"}");
 	tc.movePosition(QTextCursor::Up,QTextCursor::MoveAnchor,1);
 	setTextCursor(tc);
 	if (insert_word.contains(QString(0x2022)))
@@ -1459,7 +1474,6 @@ ensureCursorVisible();
 
 void LatexEditor::removeStructureItem(int offset,int len, int line)
 {
-
 bool r=false;
 for ( int j=StructItemsList.count()-1;j>=0; --j ) 
   {
@@ -1539,3 +1553,32 @@ void LatexEditor::setLastSavedTime(QDateTime t)
 lastSavedTime=t;  
 }
 
+QString LatexEditor::beginningLine()
+{
+QString result="";
+QTextCursor cursor=textCursor();
+QTextBlock block=cursor.block();
+if (block.isValid()) 
+	{
+	QString txt=block.text();
+	int j=0;
+	while ( (j<txt.count()) && ((txt[j]==' ') || txt[j]=='\t') ) 
+		{
+		result+=QString(txt[j]);
+		j++;
+		}
+
+	}
+return result;
+}
+/*const QRectF LatexEditor::blockGeometry(const QTextBlock & block) 
+{
+qDebug() << "ok1" << block.isValid() << block.isVisible();
+//if (block.isVisible()) return blockBoundingGeometry(block).translated(contentOffset());
+//else return QRectF();
+return blockBoundingGeometry(block).translated(contentOffset());
+//const QRectF rec=blockBoundingGeometry(block);
+//qDebug() << "ok2";
+//if (rec.isValid()) return rec.translated(contentOffset());
+//else return QRectF();
+}*/
