@@ -95,7 +95,7 @@ const int StateGraphic =8;
 const int StateGraphicCommand =9;
 const int StateGraphicMath =10;
 const int StateBib =11;
-const int StateBibCommand =12;
+//const int StateBibCommand =12;
 
 BlockData *blockData = new BlockData;
 int leftPos = text.indexOf( '{' );
@@ -180,7 +180,8 @@ offset=tagStart;
 	{
 	tagStart=s.indexOf(struct_level3, tagEnd);
 	s=s.mid(tagStart+struct_level3.length(),s.length());
-		tagStart=s.indexOf("}", tagEnd);
+	s=s.trimmed();
+	tagStart=s.indexOf("}", tagEnd);
 	if (tagStart!=-1)
 	  {
 	  if (s.startsWith("*")) s=s.remove(0,1);
@@ -204,6 +205,7 @@ if (tagStart!=-1)
 	{
 	tagStart=s.indexOf(struct_level4, tagEnd);
 	s=s.mid(tagStart+struct_level4.length(),s.length());
+	s=s.trimmed();
 	tagStart=s.indexOf("}", tagEnd);
 	if (tagStart!=-1)
 	  {
@@ -229,6 +231,7 @@ if (tagStart!=-1)
 	{
 	tagStart=s.indexOf(struct_level5, tagEnd);
 	s=s.mid(tagStart+struct_level5.length(),s.length());
+	s=s.trimmed();
 	tagStart=s.indexOf("}", tagEnd);
 	if (tagStart!=-1)
 	  {
@@ -254,7 +257,6 @@ if (tagStart!=-1)
 	{
 	tagStart=s.indexOf("begin{block}", tagEnd);
 	s=s.mid(tagStart+12,s.length());
-
 	if (s.startsWith("{")) s=s.remove(0,1);
 	if (s.endsWith("}")) s=s.remove(s.length()-1,1);
 	//s=s+" (line "+QString::number(i+1)+")";
@@ -274,6 +276,7 @@ offset=tagStart;
 if (tagStart!=-1)
 	{
 	s=s.mid(tagStart+7,s.length());
+	s=s.trimmed();
 	tagStart=s.indexOf("}", tagEnd);
 	if (tagStart!=-1)
 		{
@@ -298,6 +301,7 @@ offset=tagStart;
 if (tagStart!=-1)
 	{
 	s=s.mid(tagStart+8,s.length());
+	s=s.trimmed();
 	tagStart=s.indexOf("}", tagEnd);
 	if (tagStart!=-1)
 		{
@@ -321,6 +325,7 @@ offset=tagStart;
 	if (tagStart!=-1)
 	{
 	s=s.mid(tagStart+6,s.length());
+	s=s.trimmed();
 	tagStart=s.indexOf("}", tagEnd);
 	if (tagStart!=-1)
 		{
@@ -345,6 +350,7 @@ if (tagStart!=-1)
 	{
 	tagStart=s.indexOf(struct_level1, tagEnd);
 	s=s.mid(tagStart+struct_level1.length(),s.length());
+	s=s.trimmed();
 	tagStart=s.indexOf("}", tagEnd);
 	if (tagStart!=-1)
 	  {
@@ -370,6 +376,7 @@ if (tagStart!=-1)
 	{
 	tagStart=s.indexOf(struct_level2, tagEnd);
 	s=s.mid(tagStart+struct_level2.length(),s.length());
+	s=s.trimmed();
 	tagStart=s.indexOf("}", tagEnd);
 	if (tagStart!=-1)
 	  {
@@ -394,6 +401,31 @@ offset=tagStart;
 if (tagStart!=-1)
 	{
 	s=s.mid(tagStart+13,s.length());
+	s=s.trimmed();
+	tagStart=s.indexOf("}", tagEnd);
+	if (tagStart!=-1)
+		{
+		s=s.mid(0,tagStart+1);
+		if (s.startsWith("{")) s=s.remove(0,1);
+		if (s.endsWith("}")) s=s.remove(s.length()-1,1);
+				      	QTextCursor	cursor(document());
+	cursor.setPosition(currentBlock().position() + offset+1);
+	//cursor.setPosition(currentBlock().position() + offset + 1, QTextCursor::KeepAnchor);
+		editor->appendStructureItem(i,s,9,cursor);found=true;
+		}
+	};
+}
+if (!found)
+{
+//// bib files ////
+tagStart=tagEnd=offset=0;
+s=text;
+tagStart=s.indexOf("\\addbibresource{", tagEnd);
+offset=tagStart;
+if (tagStart!=-1)
+	{
+	s=s.mid(tagStart+15,s.length());
+	s=s.trimmed();
 	tagStart=s.indexOf("}", tagEnd);
 	if (tagStart!=-1)
 		{
@@ -1007,16 +1039,17 @@ while (i < text.length())
 	} break;
 /****************************/
        case StateBib: {
+//	 qDebug() << "bib" << buffer << next;
                tmp=text.at( i );
-		if (tmp== '\"' ){
+/*		if (tmp== '\"' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
 			state=StateBibCommand;
-		} else
+		} else*/
 		if (tmp== '}' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
-			if (next!=',')
+			if (next=='\n' || i == text.length()-1)
 			  {
 			  state=StateStandard;
 			  buffer = QString::null;
@@ -1028,18 +1061,31 @@ while (i < text.length())
 			//buffer = QString::null;
 		}
        } break;
-       case StateBibCommand: {
+/*       case StateBibCommand: {
+	 	 qDebug() << "bibcommand" << buffer;
                tmp=text.at( i );
 		if (tmp== '\"' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
 			state=StateBib;
+		} else
+		if (tmp== '}' ){
+			blockData->code[i]=1;
+			setFormat( i, 1,ColorVerbatim);
+			if (next!=',' || i == text.length()-1)
+			  {
+			  state=StateBib;
+			  }
+			else 
+			{
+			 state=StateBibCommand; 
+			}
 		} else
 		 {
 			setFormat( i, 1,ColorVerbatim);
 			state=StateBibCommand;
 		}
-       } break;
+       } break;*/
 /***************************/
        case StateSweave: {
                tmp=text.at( i );
@@ -1219,10 +1265,10 @@ else if ( state == StateBib )
        {
        setCurrentBlockState(StateBib) ;
        }
-else if ( state == StateBibCommand ) 
+/*else if ( state == StateBibCommand ) 
        {
        setCurrentBlockState(StateBibCommand) ;
-       } 
+       } */
 else 
 	{
 	setCurrentBlockState(StateStandard) ;
