@@ -307,7 +307,7 @@ void ManhattanStyle::polish(QWidget *widget)
             widget->removeEventFilter(d->style);
     }
     if (panelWidget(widget)) {
-        if (qobject_cast<QToolButton*>(widget)) {
+        /*if (qobject_cast<QToolButton*>(widget)) {
             widget->setAttribute(Qt::WA_Hover);
             widget->setMaximumHeight(StyleHelper::navigationWidgetHeight() - 2);
             widget->setAttribute(Qt::WA_Hover);
@@ -316,16 +316,16 @@ void ManhattanStyle::polish(QWidget *widget)
             widget->setAttribute(Qt::WA_Hover);
             widget->setMaximumHeight(StyleHelper::navigationWidgetHeight() - 2);
         }
-        else if (qobject_cast<QLabel*>(widget))
+        else*/ if (qobject_cast<QLabel*>(widget))
             widget->setPalette(panelPalette(widget->palette()));
-        else if (qobject_cast<QToolBar*>(widget))
+       /* else if (qobject_cast<QToolBar*>(widget))
             widget->setMinimumHeight(StyleHelper::navigationWidgetHeight());
 //        else if (qobject_cast<QStatusBar*>(widget))
 //            widget->setFixedHeight(StyleHelper::navigationWidgetHeight() + 2);
         else if (qobject_cast<QComboBox*>(widget)) {
             widget->setMaximumHeight(StyleHelper::navigationWidgetHeight() - 2);
             widget->setAttribute(Qt::WA_Hover);
-        }
+        }*/
     }
 }
 
