@@ -1,6 +1,6 @@
 /***************************************************************************
- *   copyright            : (C) 2003 by Pascal Brachet                     *
- *                                                                         *
+ *   copyright       : (C) 2003-2009 by Pascal Brachet                     *
+ *   http://www.xm1math.net/texmaker/                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,44 +12,31 @@
 #ifndef USERTOOLDIALOG_H
 #define USERTOOLDIALOG_H
 
-#include <qwidget.h>
-#include <qdialog.h>
-#include <qlayout.h>
-#include <qlabel.h>
-#include <qlineedit.h>
-#include <qcombobox.h>
-#include <qpushbutton.h>
-#include <qstring.h>
+#include <QString>
+#include "ui_usertooldialog.h"
 
 typedef QString userCd[5];
 
-/**
-  *@author Pascal Brachet
-  */
 
-class usertooldialog : public QDialog  {
+class UserToolDialog : public QDialog  {
    Q_OBJECT
 public: 
-	usertooldialog(QWidget *parent=0, const char *name=0);
-	~usertooldialog();
+	UserToolDialog(QWidget *parent=0, QString name="");
+	~UserToolDialog();
+	Ui::UserToolDialog ui;
 
       userCd Name,Tool;
 
 private:
     int previous_index;
-    QLineEdit *itemedit, *tooledit;
-    QComboBox *combo1;
-    QLabel* label1;
-    QLabel* label2;
-	  QPushButton *buttonOk;
-	  QPushButton *buttonCancel;
 
 public slots:
     void init();
 
 private slots:
     void change(int index);
-    void slotOk();  
+    void slotOk();
+    void updateItem();
 };
 
 #endif
